Here's my summer project, a re-imagining of the anchor module. It is now built on top of scripter and the ui.View update method. As a result, it is much more flexible and does not crash.

First a couple of pictures to show the anchors in action. The second picture is the same as the first one, after rotating the phone to landscape. A sharp eye may notice some of the dynamic features enabled by the anchors.

